@@ -4,6 +4,7 @@ import ConfigParser
 import datetime
 import os
 import os.path as osp
+import platform
 import pkg_resources
 import re
 import shlex
@@ -147,10 +148,9 @@ def _archive(push=True):
             todos_archive.append(todo)
         else:
             todos_remain.append(todo)
-    content_archive = render_todo(date, todos_archive)
-
-    if not content_archive:
+    if not todos_archive:
         return
+    content_archive = render_todo(date, todos_archive)
 
     # archive
     archive_dir = osp.join(CACHE_DIR, date.strftime('%Y'))
@@ -168,6 +168,15 @@ def _archive(push=True):
         _push_cache_dir()
 
 
+def _get_open_cmd():
+    if platform.uname()[0] == 'Linux':
+        return 'gnome-open'
+    elif platform.uname()[0] == 'Darwin':
+        return 'open'
+    else:
+        raise RuntimeError('Unsupported OS for open command')
+
+
 # -----------------------------------------------------------------------------
 
 
@@ -184,32 +193,16 @@ def cmd_init(remote_url):
     _pull_cache_dir()
 
 
-def _ask_yn(prompt):
-    yes = None
-    while True:
-        yn = raw_input(prompt)
-        yn = yn.lower()
-        if yn in ['y', 'yes']:
-            yes = True
-            break
-        elif yn in ['n', 'no']:
-            yes = False
-            break
-        else:
-            print('Select [y/n]')
-    return yes
-
-
 @cli.command('deinit', help='Uninitialize')
 def cmd_deinit():
     if osp.exists(CONFIG_FILE):
         prompt = 'Can I remove config file "{:s}"? [y/n]: '.format(CONFIG_FILE)
-        if _ask_yn(prompt):
+        if click.confirm(prompt):
             os.remove(CONFIG_FILE)
 
     if osp.exists(CACHE_DIR):
         prompt = 'Can I remove cache dir "{:s}"? [y/n]: '.format(CACHE_DIR)
-        if _ask_yn(prompt):
+        if click.confirm(prompt):
             shutil.rmtree(CACHE_DIR)
 
 
@@ -244,7 +237,8 @@ def cmd_open():
     _init()
     _archive()
     readme_url = osp.join(osp.splitext(GITHUB_URL)[0], 'blob/master/README.md')
-    cmd = 'open {url}'.format(url=readme_url)
+    readme_url += datetime.date.today().strftime('#%Y-%m-%d')
+    cmd = '{cmd} {url}'.format(cmd=_get_open_cmd(), url=readme_url)
     print('Opening {:s}'.format(readme_url))
     subprocess.call(cmd, shell=True)
 
